==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebColumnSelectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnSelectionEventArgsDetailDescriptionMetadata } from "./WebColumnSelectionEventArgsDetailDescriptionMetadata";
import { WebColumnSelectionEventArgsDescription } from "./WebColumnSelectionEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnSelectionEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnSelectionEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnSelectionEventArgsDescriptionMetadata.a == null) {
                WebColumnSelectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnSelectionEventArgsDescriptionMetadata.c(WebColumnSelectionEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebColumnSelectionEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebColumnSelectionEventArgsDescriptionMetadata.a);
            WebColumnSelectionEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnSelectionEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebColumnSelectionEventArgsDetail");
        }
        static d(a) {
            WebColumnSelectionEventArgsDescriptionMetadata.b(a);
            a.aa("WebColumnSelectionEventArgs", () => new WebColumnSelectionEventArgsDescription());
            a.z("WebColumnSelectionEventArgs", WebColumnSelectionEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnSelectionEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnSelectionEventArgsDescriptionMetadata, 'WebColumnSelectionEventArgsDescriptionMetadata');
    WebColumnSelectionEventArgsDescriptionMetadata.a = null;
    return WebColumnSelectionEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnSelectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnSelectionEventArgsDetailDescriptionMetadata } from "./WebColumnSelectionEventArgsDetailDescriptionMetadata";
import { WebColumnSelectionEventArgsDescription } from "./WebColumnSelectionEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnSelectionEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnSelectionEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnSelectionEventArgsDescriptionMetadata.a == null) {
                WebColumnSelectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnSelectionEventArgsDescriptionMetadata.c(WebColumnSelectionEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnSelectionEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebColumnSelectionEventArgsDescriptionMetadata.a);
            WebColumnSelectionEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnSelectionEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebColumnSelectionEventArgsDetail");
        }
        static d(a) {
            WebColumnSelectionEventArgsDescriptionMetadata.b(a);
            a.ac("WebColumnSelectionEventArgs", () => new WebColumnSelectionEventArgsDescription());
            a.ab("WebColumnSelectionEventArgs", WebColumnSelectionEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnSelectionEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnSelectionEventArgsDescriptionMetadata, 'WebColumnSelectionEventArgsDescriptionMetadata');
    WebColumnSelectionEventArgsDescriptionMetadata.a = null;
    return WebColumnSelectionEventArgsDescriptionMetadata;
})();
